You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2015/02/02 14:55:09 UTC

[3/3] incubator-ignite git commit: #IGNITE-106: Remove grid from comments.

#IGNITE-106: Remove grid from comments.


Project: http://git-wip-us.apache.org/repos/asf/incubator-ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-ignite/commit/921fd0c7
Tree: http://git-wip-us.apache.org/repos/asf/incubator-ignite/tree/921fd0c7
Diff: http://git-wip-us.apache.org/repos/asf/incubator-ignite/diff/921fd0c7

Branch: refs/heads/ignite-106
Commit: 921fd0c7896b1fcde5bcf4caa9c6d98e7f9852b6
Parents: 8c83e3a
Author: ivasilinets <iv...@gridgain.com>
Authored: Mon Feb 2 16:54:57 2015 +0300
Committer: ivasilinets <iv...@gridgain.com>
Committed: Mon Feb 2 16:54:59 2015 +0300

----------------------------------------------------------------------
 examples/config/example-cache.xml               |   2 +-
 examples/config/example-streamer.xml            |   4 +-
 examples/config/filesystem/example-ggfs.xml     |   2 +-
 .../hibernate/example-hibernate-L2-cache.xml    |   2 +-
 .../apache/ignite/examples/ExamplesUtils.java   |   4 +-
 .../compute/ComputeBroadcastExample.java        |   2 +-
 .../compute/ComputeCallableExample.java         |   8 +-
 .../examples/compute/ComputeClosureExample.java |   8 +-
 .../compute/ComputeContinuousMapperExample.java |  10 +-
 .../compute/ComputeExecutorServiceExample.java  |   4 +-
 .../ComputeFibonacciContinuationExample.java    |   4 +-
 .../compute/ComputeProjectionExample.java       |   2 +-
 .../examples/compute/ComputeReducerExample.java |   6 +-
 .../compute/ComputeRunnableExample.java         |   4 +-
 .../compute/ComputeScheduleExample.java         |   2 +-
 .../examples/compute/ComputeTaskMapExample.java |  10 +-
 .../compute/ComputeTaskSplitExample.java        |  16 +-
 .../failover/ComputeFailoverExample.java        |   2 +-
 .../compute/montecarlo/CreditRiskExample.java   |  18 +--
 .../compute/montecarlo/CreditRiskManager.java   |   2 +-
 .../apache/ignite/examples/compute/package.html |   2 +-
 .../examples/datagrid/CacheAffinityExample.java |   4 +-
 .../examples/datagrid/CacheEventsExample.java   |   2 +-
 .../datagrid/CachePopularNumbersExample.java    |   2 +-
 .../examples/datagrid/CacheQueryExample.java    |   2 +-
 .../datastructures/CacheAtomicLongExample.java  |   8 +-
 .../CacheAtomicReferenceExample.java            |  12 +-
 .../CacheAtomicSequenceExample.java             |   6 +-
 .../CacheAtomicStampedExample.java              |  10 +-
 .../CacheCountDownLatchExample.java             |   6 +-
 .../datastructures/CacheQueueExample.java       |   2 +-
 .../datastructures/CacheSetExample.java         |   2 +-
 .../ignite/examples/datagrid/package.html       |   2 +-
 .../store/CacheNodeWithStoreStartup.java        |   4 +-
 .../datagrid/store/CacheStoreExample.java       |   2 +-
 .../store/dummy/CacheDummyPersonStore.java      |   2 +-
 .../ignite/examples/events/EventsExample.java   |   6 +-
 .../examples/messaging/MessagingExample.java    |   6 +-
 .../messaging/MessagingPingPongExample.java     |   2 +-
 .../MessagingPingPongListenActorExample.java    |   2 +-
 .../misc/deployment/DeploymentExample.java      |   6 +-
 .../misc/lifecycle/LifecycleExample.java        |   8 +-
 .../misc/springbean/SpringBeanExample.java      |  14 +-
 .../examples/misc/springbean/spring-bean.xml    |   4 +-
 .../org/apache/ignite/examples/package.html     |   2 +-
 .../streaming/StreamingCheckInExample.java      |   4 +-
 .../StreamingPopularNumbersExample.java         |   6 +-
 .../streaming/StreamingPriceBarsExample.java    |   2 +-
 .../apache/ignite/examples/ComputeExample.java  |   9 +-
 .../ignite/examples/MessagingExample.java       |  10 +-
 .../examples/ScalarCacheAffinityExample1.scala  |   6 +-
 .../examples/ScalarCacheAffinityExample2.scala  |   8 +-
 .../ScalarCacheAffinitySimpleExample.scala      |   4 +-
 .../scalar/examples/ScalarCacheExample.scala    |   2 +-
 .../ScalarCachePopularNumbersExample.scala      |   6 +-
 .../examples/ScalarCacheQueryExample.scala      |   2 +-
 .../scalar/examples/ScalarClosureExample.scala  |  16 +-
 .../examples/ScalarContinuationExample.scala    |  16 +-
 .../examples/ScalarCreditRiskExample.scala      |   4 +-
 .../examples/ScalarPiCalculationExample.scala   |   4 +-
 .../scalar/examples/ScalarPingPongExample.scala |   6 +-
 .../scalar/examples/ScalarPrimeExample.scala    |   4 +-
 .../scalar/examples/ScalarScheduleExample.scala |   6 +-
 .../examples/ScalarSnowflakeSchemaExample.scala |   8 +-
 .../scalar/examples/ScalarTaskExample.scala     |   2 +-
 .../examples/ScalarWorldShortestMapReduce.scala |   2 +-
 .../BasicExamplesMultiNodeSelfTest.java         |  28 ++++
 .../ignite/examples/BasicExamplesSelfTest.java  |  82 ++++++++++
 .../CacheExamplesMultiNodeSelfTest.java         |  48 ++++++
 .../ignite/examples/CacheExamplesSelfTest.java  | 155 +++++++++++++++++++
 ...heStoreLoadDataExampleMultiNodeSelfTest.java |  39 +++++
 .../examples/CheckpointExamplesSelfTest.java    |  45 ++++++
 .../ContinuationExamplesMultiNodeSelfTest.java  |  28 ++++
 .../examples/ContinuationExamplesSelfTest.java  |  33 ++++
 ...ntinuousMapperExamplesMultiNodeSelfTest.java |  28 ++++
 .../ContinuousMapperExamplesSelfTest.java       |  33 ++++
 .../DeploymentExamplesMultiNodeSelfTest.java    |  30 ++++
 .../examples/DeploymentExamplesSelfTest.java    |  33 ++++
 .../EventsExamplesMultiNodeSelfTest.java        |  28 ++++
 .../ignite/examples/EventsExamplesSelfTest.java |  33 ++++
 .../GridBasicExamplesMultiNodeSelfTest.java     |  28 ----
 .../examples/GridBasicExamplesSelfTest.java     |  82 ----------
 .../GridCacheExamplesMultiNodeSelfTest.java     |  48 ------
 .../examples/GridCacheExamplesSelfTest.java     | 155 -------------------
 ...heStoreLoadDataExampleMultiNodeSelfTest.java |  39 -----
 .../GridCheckpointExamplesSelfTest.java         |  45 ------
 ...idContinuationExamplesMultiNodeSelfTest.java |  28 ----
 .../GridContinuationExamplesSelfTest.java       |  33 ----
 ...ntinuousMapperExamplesMultiNodeSelfTest.java |  28 ----
 .../GridContinuousMapperExamplesSelfTest.java   |  33 ----
 ...GridDeploymentExamplesMultiNodeSelfTest.java |  30 ----
 .../GridDeploymentExamplesSelfTest.java         |  33 ----
 .../GridEventsExamplesMultiNodeSelfTest.java    |  28 ----
 .../examples/GridEventsExamplesSelfTest.java    |  33 ----
 ...ibernateL2CacheExampleMultiNodeSelfTest.java |  31 ----
 .../GridHibernateL2CacheExampleSelfTest.java    |  33 ----
 .../examples/GridLifecycleExamplesSelfTest.java |  33 ----
 ...idMemcacheRestExamplesMultiNodeSelfTest.java |  31 ----
 .../GridMemcacheRestExamplesSelfTest.java       |  41 -----
 .../examples/GridMessagingExamplesSelfTest.java |  52 -------
 ...GridMonteCarloExamplesMultiNodeSelfTest.java |  28 ----
 .../GridMonteCarloExamplesSelfTest.java         |  74 ---------
 .../examples/GridProjectionExampleSelfTest.java |  39 -----
 .../GridSpringBeanExamplesSelfTest.java         |  33 ----
 .../GridTaskExamplesMultiNodeSelfTest.java      |  28 ----
 .../examples/GridTaskExamplesSelfTest.java      |  40 -----
 ...ibernateL2CacheExampleMultiNodeSelfTest.java |  31 ++++
 .../HibernateL2CacheExampleSelfTest.java        |  33 ++++
 .../examples/IgniteFsExamplesSelfTest.java      |   2 +-
 .../examples/LifecycleExamplesSelfTest.java     |  33 ++++
 .../MemcacheRestExamplesMultiNodeSelfTest.java  |  31 ++++
 .../examples/MemcacheRestExamplesSelfTest.java  |  41 +++++
 .../examples/MessagingExamplesSelfTest.java     |  52 +++++++
 .../MonteCarloExamplesMultiNodeSelfTest.java    |  28 ++++
 .../examples/MonteCarloExamplesSelfTest.java    |  74 +++++++++
 .../examples/ProjectionExampleSelfTest.java     |  39 +++++
 .../examples/SpringBeanExamplesSelfTest.java    |  33 ++++
 .../examples/TaskExamplesMultiNodeSelfTest.java |  28 ++++
 .../ignite/examples/TaskExamplesSelfTest.java   |  40 +++++
 .../testsuites/IgniteExamplesSelfTestSuite.java |  52 +++----
 .../tests/examples/ScalarExamplesSelfTest.scala |   4 +-
 .../apache/ignite/internal/IgniteKernal.java    |   4 +-
 .../apache/ignite/lifecycle/LifecycleBean.java  |   4 +-
 .../ignite/lifecycle/LifecycleEventType.java    |   4 +-
 .../internal/GridLifecycleBeanSelfTest.java     |  38 ++---
 .../dht/GridCacheDhtPreloadBigDataSelfTest.java |   2 +-
 .../dht/GridCacheDhtPreloadUnloadSelfTest.java  |   2 +-
 ...achePartitionedPreloadLifecycleSelfTest.java |   4 +-
 ...CacheReplicatedPreloadLifecycleSelfTest.java |   4 +-
 .../colocation/GridTestLifecycleBean.java       |   2 +-
 .../loadtests/dsi/GridDsiLifecycleBean.java     |   4 +-
 .../junits/common/AbstractExamplesTest.java     |  79 ++++++++++
 .../junits/common/GridAbstractExamplesTest.java |  79 ----------
 .../scala/org/apache/ignite/scalar/scalar.scala |  10 +-
 .../tests/ScalarAffinityRoutingSpec.scala       |  12 +-
 .../tests/ScalarCacheProjectionSpec.scala       |   2 +-
 .../ignite/scalar/tests/ScalarCacheSpec.scala   |   2 +-
 .../ignite/internal/GridFactorySelfTest.java    |   6 +-
 138 files changed, 1442 insertions(+), 1443 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/config/example-cache.xml
----------------------------------------------------------------------
diff --git a/examples/config/example-cache.xml b/examples/config/example-cache.xml
index 70ffa80..ec02084 100644
--- a/examples/config/example-cache.xml
+++ b/examples/config/example-cache.xml
@@ -18,7 +18,7 @@
   -->
 
 <!--
-    Ignite Spring configuration file to startup grid cache.
+    Ignite Spring configuration file to startup ignite cache.
 
     When starting a standalone node, you need to execute the following command:
     {IGNITE_HOME}/bin/ignite.{bat|sh} examples/config/example-cache.xml

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/config/example-streamer.xml
----------------------------------------------------------------------
diff --git a/examples/config/example-streamer.xml b/examples/config/example-streamer.xml
index 0d9c024..c22b19b 100644
--- a/examples/config/example-streamer.xml
+++ b/examples/config/example-streamer.xml
@@ -18,7 +18,7 @@
   -->
 
 <!--
-    Ignite Spring configuration file to startup grid with streamers.
+    Ignite Spring configuration file to startup ignite with streamers.
 
     When starting a standalone node, you need to execute the following command:
     {IGNITE_HOME}/bin/ignite.{bat|sh} examples/config/example-streamer.xml
@@ -43,7 +43,7 @@
     </description>
 
     <!--
-        Configuration below demonstrates how to setup caches within grid nodes.
+        Configuration below demonstrates how to setup caches within cluster nodes.
     -->
     <bean id="grid.cfg" class="org.apache.ignite.configuration.IgniteConfiguration">
         <property name="marshaller">

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/config/filesystem/example-ggfs.xml
----------------------------------------------------------------------
diff --git a/examples/config/filesystem/example-ggfs.xml b/examples/config/filesystem/example-ggfs.xml
index 9f19a42..02a8305 100644
--- a/examples/config/filesystem/example-ggfs.xml
+++ b/examples/config/filesystem/example-ggfs.xml
@@ -18,7 +18,7 @@
   -->
 
 <!--
-    Ignite Spring configuration file to startup grid cache.
+    Ignite Spring configuration file to startup ignite cache.
 
     When starting a standalone node, you need to execute the following command:
     {IGNITE_HOME}/bin/ignite.{bat|sh} examples/config/filesystem/example-ggfs.xml

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/config/hibernate/example-hibernate-L2-cache.xml
----------------------------------------------------------------------
diff --git a/examples/config/hibernate/example-hibernate-L2-cache.xml b/examples/config/hibernate/example-hibernate-L2-cache.xml
index 0c69248..114b319 100644
--- a/examples/config/hibernate/example-hibernate-L2-cache.xml
+++ b/examples/config/hibernate/example-hibernate-L2-cache.xml
@@ -44,7 +44,7 @@
         <!-- Specify Ignite as L2 cache provider. -->
         <property name="cache.region.factory_class">org.apache.ignite.cache.hibernate.GridHibernateRegionFactory</property>
 
-        <!-- Specify the name of the grid, that will be used for second level caching. -->
+        <!-- Specify the name of the ignite, that will be used for second level caching. -->
         <property name="org.apache.ignite.hibernate.grid_name">hibernate-grid</property>
 
         <!-- Specify connection release mode. -->

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/ExamplesUtils.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/ExamplesUtils.java b/examples/src/main/java/org/apache/ignite/examples/ExamplesUtils.java
index 5098156..871b835 100644
--- a/examples/src/main/java/org/apache/ignite/examples/ExamplesUtils.java
+++ b/examples/src/main/java/org/apache/ignite/examples/ExamplesUtils.java
@@ -72,7 +72,7 @@ public class ExamplesUtils {
 
         if (prjSize < size) {
             System.out.println();
-            System.out.println(">>> Please start at least " + size + " grid nodes to run example.");
+            System.out.println(">>> Please start at least " + size + " cluster nodes to run example.");
             System.out.println();
 
             return false;
@@ -84,7 +84,7 @@ public class ExamplesUtils {
     /**
      * @param ignite Ignite.
      * @param name Streamer name.
-     * @return {@code True} if grid has streamer with given name.
+     * @return {@code True} if ignite has streamer with given name.
      */
     public static boolean hasStreamer(Ignite ignite, String name) {
         if (ignite.configuration().getStreamerConfiguration() != null) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/ComputeBroadcastExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeBroadcastExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeBroadcastExample.java
index b7a2612..beb322e 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeBroadcastExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeBroadcastExample.java
@@ -25,7 +25,7 @@ import org.apache.ignite.resources.*;
 import java.util.*;
 
 /**
- * Demonstrates broadcasting computations within grid projection.
+ * Demonstrates broadcasting computations within projection.
  * <p>
  * Remote nodes should always be started with special configuration file which
  * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-compute.xml'}.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/ComputeCallableExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeContinuousMapperExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeContinuousMapperExample.java
index ce78041..dbbd41b 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeContinuousMapperExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeContinuousMapperExample.java
@@ -33,7 +33,7 @@ import java.util.concurrent.atomic.*;
  * initial {@link org.apache.ignite.compute.ComputeTask#map(List, Object)} method completes.
  * <p>
  * String "Hello Continuous Mapper" is passed as an argument for execution
- * of {@link GridContinuousMapperTask}. As an outcome, participating
+ * of {@link org.apache.ignite.examples.compute.ComputeContinuousMapperExample.ContinuousMapperTask}. As an outcome, participating
  * nodes will print out a single word from the passed in string and return
  * number of characters in that word. However, to demonstrate continuous
  * mapping, next word will be mapped to a node only after the result from
@@ -57,7 +57,7 @@ public class ComputeContinuousMapperExample {
         System.out.println(">>> Compute continuous mapper example started.");
 
         try (Ignite ignite = Ignition.start("examples/config/example-compute.xml")) {
-            int phraseLen = ignite.compute().execute(GridContinuousMapperTask.class, "Hello Continuous Mapper");
+            int phraseLen = ignite.compute().execute(ContinuousMapperTask.class, "Hello Continuous Mapper");
 
             System.out.println();
             System.out.println(">>> Total number of characters in the phrase is '" + phraseLen + "'.");
@@ -75,7 +75,7 @@ public class ComputeContinuousMapperExample {
      * and therefore don't need to accumulate them be be processed at reduction step.
      */
     @ComputeTaskNoResultCache
-    private static class GridContinuousMapperTask extends ComputeTaskAdapter<String, Integer> {
+    private static class ContinuousMapperTask extends ComputeTaskAdapter<String, Integer> {
         /** This field will be injected with task continuous mapper. */
         @IgniteTaskContinuousMapperResource
         private ComputeTaskContinuousMapper mapper;
@@ -87,7 +87,7 @@ public class ComputeContinuousMapperExample {
         private final AtomicInteger totalChrCnt = new AtomicInteger(0);
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> grid, String phrase)
+        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> nodes, String phrase)
             throws IgniteCheckedException {
             if (phrase == null || phrase.isEmpty())
                 throw new IgniteCheckedException("Phrase is empty.");
@@ -140,7 +140,7 @@ public class ComputeContinuousMapperExample {
                         String word = argument(0);
 
                         System.out.println();
-                        System.out.println(">>> Printing '" + word + "' from grid job at time: " + new Date());
+                        System.out.println(">>> Printing '" + word + "' from igntie job at time: " + new Date());
 
                         int cnt = word.length();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/ComputeExecutorServiceExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeExecutorServiceExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeExecutorServiceExample.java
index 62ab8a4..36079fc 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeExecutorServiceExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeExecutorServiceExample.java
@@ -54,7 +54,7 @@ public final class ComputeExecutorServiceExample {
                 exec.submit(new IgniteRunnable() {
                     @Override public void run() {
                         System.out.println();
-                        System.out.println(">>> Printing '" + word + "' on this node from grid job.");
+                        System.out.println(">>> Printing '" + word + "' on this node from igntie job.");
                     }
                 });
             }
@@ -65,7 +65,7 @@ public final class ComputeExecutorServiceExample {
             exec.awaitTermination(0, TimeUnit.MILLISECONDS);
 
             System.out.println();
-            System.out.println(">>> Check all nodes for output (this node is also part of the grid).");
+            System.out.println(">>> Check all nodes for output (this node is also part of the cluster).");
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/ComputeFibonacciContinuationExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeProjectionExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeProjectionExample.java
index a363578..9f54d6d 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeProjectionExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeProjectionExample.java
@@ -48,7 +48,7 @@ public class ComputeProjectionExample {
 
             IgniteCluster cluster = ignite.cluster();
 
-            // Say hello to all nodes in the grid, including local node.
+            // Say hello to all nodes in the cluster, including local node.
             sayHello(ignite, cluster);
 
             // Say hello to all remote nodes.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/ComputeReducerExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeReducerExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeReducerExample.java
index 7aed33e..19a4034 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeReducerExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeReducerExample.java
@@ -25,7 +25,7 @@ import java.util.*;
 import java.util.concurrent.atomic.*;
 
 /**
- * Demonstrates a simple use of Ignite grid with reduce closure.
+ * Demonstrates a simple use of Ignite with reduce closure.
  * <p>
  * Phrase is split into words and distributed across nodes where length of each word is
  * calculated. Then total phrase length is calculated using reducer.
@@ -52,7 +52,7 @@ public class ComputeReducerExample {
                 new IgniteClosure<String, Integer>() {
                     @Override public Integer apply(String word) {
                         System.out.println();
-                        System.out.println(">>> Printing '" + word + "' on this node from grid job.");
+                        System.out.println(">>> Printing '" + word + "' on this node from igntie job.");
 
                         // Return number of letters in the word.
                         return word.length();
@@ -83,7 +83,7 @@ public class ComputeReducerExample {
 
             System.out.println();
             System.out.println(">>> Total number of characters in the phrase is '" + sum + "'.");
-            System.out.println(">>> Check all nodes for output (this node is also part of the grid).");
+            System.out.println(">>> Check all nodes for output (this node is also part of the cluster).");
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/ComputeRunnableExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeRunnableExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeRunnableExample.java
index b6fe8d9..9465779 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeRunnableExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeRunnableExample.java
@@ -56,7 +56,7 @@ public class ComputeRunnableExample {
                 compute.run(new IgniteRunnable() {
                     @Override public void run() {
                         System.out.println();
-                        System.out.println(">>> Printing '" + word + "' on this node from grid job.");
+                        System.out.println(">>> Printing '" + word + "' on this node from igntie job.");
                     }
                 });
 
@@ -69,7 +69,7 @@ public class ComputeRunnableExample {
 
             System.out.println();
             System.out.println(">>> Finished printing words using runnable execution.");
-            System.out.println(">>> Check all nodes for output (this node is also part of the grid).");
+            System.out.println(">>> Check all nodes for output (this node is also part of the cluster).");
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/ComputeScheduleExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeScheduleExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeScheduleExample.java
index 6cd7fc7..fb1dca1 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeScheduleExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeScheduleExample.java
@@ -26,7 +26,7 @@ import java.util.concurrent.*;
 
 /**
  * Demonstrates a cron-based {@link Runnable} execution scheduling.
- * Test runnable object broadcasts a phrase to all grid nodes every minute
+ * Test runnable object broadcasts a phrase to all cluster nodes every minute
  * three times with initial scheduling delay equal to five seconds.
  * <p>
  * Remote nodes should always be started with special configuration file which

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/ComputeTaskMapExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/failover/ComputeFailoverExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/failover/ComputeFailoverExample.java
index 23fbbe9..5471adf 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/failover/ComputeFailoverExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/failover/ComputeFailoverExample.java
@@ -79,7 +79,7 @@ public class ComputeFailoverExample {
         /**
          * The job will check the checkpoint with key '{@code fail}' and if
          * it's {@code true} it will throw exception to simulate a failure.
-         * Otherwise, it will execute the grid-enabled method.
+         * Otherwise, it will execute enabled method.
          */
         @Override public Integer apply(String phrase) {
             System.out.println();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskManager.java b/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskManager.java
index 085dac3..3bf7f55 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskManager.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskManager.java
@@ -26,7 +26,7 @@ import java.util.*;
 public class CreditRiskManager {
     /**
      * Default randomizer with normal distribution.
-     * Note that since every JVM on the grid will have its own random
+     * Note that since every JVM on the cluster will have its own random
      * generator (independently initialized) the Monte-Carlo simulation
      * will be slightly skewed when performed on the grid due to skewed
      * normal distribution of the sub-jobs comparing to execution on the

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/package.html
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/package.html b/examples/src/main/java/org/apache/ignite/examples/compute/package.html
index 84ae465..5e8d2e2 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/package.html
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/package.html
@@ -18,6 +18,6 @@
 <html>
 <body>
     <!-- Package description. -->
-    Basic examples for computational grid functionality.
+    Basic examples for computational ignite functionality.
 </body>
 </html>

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheAffinityExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheAffinityExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheAffinityExample.java
index e75e781..5c7f246 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheAffinityExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheAffinityExample.java
@@ -61,10 +61,10 @@ public final class CacheAffinityExample {
             for (int i = 0; i < KEY_CNT; i++)
                 cache.put(i, Integer.toString(i));
 
-            // Co-locates jobs with data using GridCompute.affinityRun(...) method.
+            // Co-locates jobs with data using IgniteCompute.affinityRun(...) method.
             visitUsingAffinityRun();
 
-            // Co-locates jobs with data using Grid.mapKeysToNodes(...) method.
+            // Co-locates jobs with data using IgniteCluster.mapKeysToNodes(...) method.
             visitUsingMapKeysToNodes();
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheEventsExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheEventsExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheEventsExample.java
index 1aabeb8..52e585e 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheEventsExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheEventsExample.java
@@ -27,7 +27,7 @@ import java.util.*;
 import static org.apache.ignite.events.IgniteEventType.*;
 
 /**
- * This examples demonstrates events API. Note that grid events are disabled by default and
+ * This examples demonstrates events API. Note that ignite events are disabled by default and
  * must be specifically enabled, just like in {@code examples/config/example-cache.xml} file.
  * <p>
  * Remote nodes should always be started with special configuration file which

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java
index 1dc1246..1e86ca7 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CachePopularNumbersExample.java
@@ -39,7 +39,7 @@ public class CachePopularNumbersExample {
     /** Cache name. */
     private static final String CACHE_NAME = "partitioned";
 
-    /** Count of most popular numbers to retrieve from grid. */
+    /** Count of most popular numbers to retrieve from cluster. */
     private static final int POPULAR_NUMBERS_CNT = 10;
 
     /** Random number generator. */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java
index 773133c..495fa43 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/CacheQueryExample.java
@@ -27,7 +27,7 @@ import java.io.*;
 import java.util.*;
 
 /**
- * Grid cache queries example. This example demonstrates SQL, TEXT, and FULL SCAN
+ * Cache queries example. This example demonstrates SQL, TEXT, and FULL SCAN
  * queries over cache.
  * <p>
  * Example also demonstrates usage of fields queries that return only required

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicLongExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicLongExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicLongExample.java
index f6c6662..53274da 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicLongExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicLongExample.java
@@ -51,17 +51,17 @@ public final class CacheAtomicLongExample {
             System.out.println();
             System.out.println(">>> Cache atomic long example started.");
 
-            // Make name for atomic long (by which it will be known in the grid).
+            // Make name for atomic long (by which it will be known in the cluster).
             String atomicName = UUID.randomUUID().toString();
 
-            // Initialize atomic long in grid.
+            // Initialize atomic long in ignite.
             final CacheAtomicLong atomicLong = ignite.cache(CACHE_NAME).dataStructures().atomicLong(atomicName, 0, true);
 
             System.out.println();
             System.out.println("Atomic long initial value : " + atomicLong.get() + '.');
 
-            // Try increment atomic long from all grid nodes.
-            // Note that this node is also part of the grid.
+            // Try increment atomic long from all cluster nodes.
+            // Note that this node is also part of the cluster.
             ignite.compute(ignite.cluster().forCache(CACHE_NAME)).call(new IgniteCallable<Object>() {
                 @Override
                 public Object call() throws Exception {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicReferenceExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheQueueExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheQueueExample.java
index d0b4a15..0a08743 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheQueueExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheQueueExample.java
@@ -25,7 +25,7 @@ import org.apache.ignite.lang.*;
 import java.util.*;
 
 /**
- * Grid cache distributed queue example. This example demonstrates {@code FIFO} unbounded
+ * Ignite cache distributed queue example. This example demonstrates {@code FIFO} unbounded
  * cache queue.
  * <p>
  * Remote nodes should always be started with special configuration file which

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheSetExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheSetExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheSetExample.java
index da49ea7..0d97a6c 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheSetExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheSetExample.java
@@ -25,7 +25,7 @@ import org.apache.ignite.lang.*;
 import java.util.*;
 
 /**
- * Grid cache distributed set example.
+ * Ignite cache distributed set example.
  * <p>
  * Remote nodes should always be started with special configuration file which
  * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-cache.xml'}.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/package.html
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/package.html b/examples/src/main/java/org/apache/ignite/examples/datagrid/package.html
index 0264c57..a21b3ad 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/package.html
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/package.html
@@ -18,6 +18,6 @@
 <html>
 <body>
     <!-- Package description. -->
-    Demonstrates data grid cache usage.
+    Demonstrates data ignite cache usage.
 </body>
 </html>

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/store/CacheNodeWithStoreStartup.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/store/CacheNodeWithStoreStartup.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/store/CacheNodeWithStoreStartup.java
index 28cfb4e..8f55bbf 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/store/CacheNodeWithStoreStartup.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/store/CacheNodeWithStoreStartup.java
@@ -46,9 +46,9 @@ public class CacheNodeWithStoreStartup {
     }
 
     /**
-     * Configure grid.
+     * Configure ignite.
      *
-     * @return Grid configuration.
+     * @return Ignite configuration.
      * @throws IgniteCheckedException If failed.
      */
     public static IgniteConfiguration configure() throws IgniteCheckedException {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/store/CacheStoreExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/store/CacheStoreExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/store/CacheStoreExample.java
index 32bb0e1..e27f4b8 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/store/CacheStoreExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/store/CacheStoreExample.java
@@ -44,7 +44,7 @@ public class CacheStoreExample {
     public static void main(String[] args) throws Exception {
         IgniteConfiguration cfg = CacheNodeWithStoreStartup.configure();
 
-        // To start grid with desired configuration uncomment the appropriate line.
+        // To start ignite with desired configuration uncomment the appropriate line.
         try (Ignite ignite = Ignition.start(cfg)) {
             System.out.println();
             System.out.println(">>> Cache store example started.");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/store/dummy/CacheDummyPersonStore.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/store/dummy/CacheDummyPersonStore.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/store/dummy/CacheDummyPersonStore.java
index fc91b80..6379140 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/store/dummy/CacheDummyPersonStore.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/store/dummy/CacheDummyPersonStore.java
@@ -32,7 +32,7 @@ import java.util.concurrent.*;
  * Dummy cache store implementation.
  */
 public class CacheDummyPersonStore extends CacheStoreAdapter<Long, Person> {
-    /** Auto-inject grid instance. */
+    /** Auto-inject igntie instance. */
     @IgniteInstanceResource
     private Ignite ignite;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/events/EventsExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/events/EventsExample.java b/examples/src/main/java/org/apache/ignite/examples/events/EventsExample.java
index 80288cc..6b5a163 100644
--- a/examples/src/main/java/org/apache/ignite/examples/events/EventsExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/events/EventsExample.java
@@ -30,7 +30,7 @@ import static org.apache.ignite.events.IgniteEventType.*;
 
 /**
  * Demonstrates event consume API that allows to register event listeners on remote nodes.
- * Note that grid events are disabled by default and must be specifically enabled,
+ * Note that ignite events are disabled by default and must be specifically enabled,
  * just like in {@code examples/config/example-compute.xml} file.
  * <p>
  * Remote nodes should always be started with configuration: {@code 'ignite.sh examples/config/example-compute.xml'}.
@@ -53,7 +53,7 @@ public class EventsExample {
             // Listen to events happening on local node.
             localListen();
 
-            // Listen to events happening on all grid nodes.
+            // Listen to events happening on all cluster nodes.
             remoteListen();
 
             // Wait for a while while callback is notified about remaining puts.
@@ -95,7 +95,7 @@ public class EventsExample {
     }
 
     /**
-     * Listen to events coming from all grid nodes.
+     * Listen to events coming from all cluster nodes.
      *
      * @throws IgniteCheckedException If failed.
      */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingExample.java b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingExample.java
index f09b10b..c8d6341 100644
--- a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingExample.java
@@ -29,7 +29,7 @@ import java.util.concurrent.*;
 /**
  * Example that demonstrates how to exchange messages between nodes. Use such
  * functionality for cases when you need to communicate to other nodes outside
- * of grid task.
+ * of ignite task.
  * <p>
  * To run this example you must have at least one remote node started.
  * <p>
@@ -71,7 +71,7 @@ public final class MessagingExample {
 
             localListen(ignite.message(ignite.cluster().forLocal()), orderedLatch, unorderedLatch);
 
-            // Register listeners on all grid nodes.
+            // Register listeners on all cluster nodes.
             startListening(ignite.message(rmtPrj));
 
             // Send unordered messages to all remote nodes.
@@ -96,7 +96,7 @@ public final class MessagingExample {
     }
 
     /**
-     * Start listening to messages on all grid nodes within passed in projection.
+     * Start listening to messages on all cluster nodes within passed in projection.
      *
      * @param msg Grid messaging.
      * @throws IgniteCheckedException If failed.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java
index 67f20ae..a69d21c 100644
--- a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongExample.java
@@ -46,7 +46,7 @@ public class MessagingPingPongExample {
      * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws IgniteCheckedException {
-        // Game is played over the default grid.
+        // Game is played over the default ignite.
         try (Ignite ignite = Ignition.start("examples/config/example-compute.xml")) {
             if (!ExamplesUtils.checkMinTopologySize(ignite.cluster(), 2))
                 return;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongListenActorExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongListenActorExample.java b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongListenActorExample.java
index 5c9416e..9a745af 100644
--- a/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongListenActorExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/messaging/MessagingPingPongListenActorExample.java
@@ -44,7 +44,7 @@ public class MessagingPingPongListenActorExample {
      * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws IgniteCheckedException {
-        // Game is played over the default grid.
+        // Game is played over the default ignite.
         try (Ignite ignite = Ignition.start("examples/config/example-compute.xml")) {
             if (!ExamplesUtils.checkMinTopologySize(ignite.cluster(), 2))
                 return;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/misc/deployment/DeploymentExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/misc/deployment/DeploymentExample.java b/examples/src/main/java/org/apache/ignite/examples/misc/deployment/DeploymentExample.java
index a234ac5..afd6072 100644
--- a/examples/src/main/java/org/apache/ignite/examples/misc/deployment/DeploymentExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/misc/deployment/DeploymentExample.java
@@ -104,10 +104,10 @@ public final class DeploymentExample {
     @ComputeTaskName(TASK_NAME)
     public static class ExampleTask extends ComputeTaskSplitAdapter<String, Object> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, String arg) throws IgniteCheckedException {
-            Collection<ComputeJob> jobs = new ArrayList<>(gridSize);
+        @Override protected Collection<? extends ComputeJob> split(int clusterSize, String arg) throws IgniteCheckedException {
+            Collection<ComputeJob> jobs = new ArrayList<>(clusterSize);
 
-            for (int i = 0; i < gridSize; i++) {
+            for (int i = 0; i < clusterSize; i++) {
                 jobs.add(new ComputeJobAdapter() {
                     @Nullable @Override public Serializable execute() {
                         System.out.println(">>> Executing deployment example job on this node.");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/misc/lifecycle/LifecycleExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/misc/springbean/spring-bean.xml b/examples/src/main/java/org/apache/ignite/examples/misc/springbean/spring-bean.xml
index 927f4d6..d5fa33d 100644
--- a/examples/src/main/java/org/apache/ignite/examples/misc/springbean/spring-bean.xml
+++ b/examples/src/main/java/org/apache/ignite/examples/misc/springbean/spring-bean.xml
@@ -18,7 +18,7 @@
   -->
 
 <!--
-    Command line (default) grid configuration.
+    Command line (default) ignite configuration.
 -->
 <beans xmlns="http://www.springframework.org/schema/beans"
        xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
@@ -26,7 +26,7 @@
        xsi:schemaLocation="
         http://www.springframework.org/schema/beans http://www.springframework.org/schema/beans/spring-beans.xsd
         http://www.springframework.org/schema/util http://www.springframework.org/schema/util/spring-util.xsd">
-    <description>Main Spring file for grid configuration.</description>
+    <description>Main Spring file for ignite configuration.</description>
 
     <!-- Example of bean definition with given configuration. -->
     <bean id="mySpringBean" class="org.apache.ignite.IgniteSpringBean">

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/package.html
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/package.html b/examples/src/main/java/org/apache/ignite/examples/package.html
index 3f503f8..02e148c 100644
--- a/examples/src/main/java/org/apache/ignite/examples/package.html
+++ b/examples/src/main/java/org/apache/ignite/examples/package.html
@@ -19,6 +19,6 @@
 <html>
 <body>
     <!-- Package description. -->
-    Basic examples for grid functionality.
+    Basic examples for ignite functionality.
 </body>
 </html>

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingCheckInExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingCheckInExample.java b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingCheckInExample.java
index a126074..347b54d 100644
--- a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingCheckInExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingCheckInExample.java
@@ -55,8 +55,8 @@ import java.util.concurrent.*;
  * {@code 'ignite.{sh|bat} examples/config/example-streamer.xml'}.
  * When starting nodes this way JAR file containing the examples code
  * should be placed to {@code IGNITE_HOME/libs} folder. You can build
- * {@code gridgain-examples.jar} by running {@code mvn package} in
- * {@code IGNITE_HOME/examples} folder. After that {@code gridgain-examples.jar}
+ * {@code ignite-examples.jar} by running {@code mvn package} in
+ * {@code IGNITE_HOME/examples} folder. After that {@code ignite-examples.jar}
  * will be generated by Maven in {@code IGNITE_HOME/examples/target} folder.
  * <p>
  * Alternatively you can run {@link StreamingNodeStartup} in another JVM which will start node

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPopularNumbersExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPopularNumbersExample.java b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPopularNumbersExample.java
index d7421ba..d249c33 100644
--- a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPopularNumbersExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPopularNumbersExample.java
@@ -38,15 +38,15 @@ import java.util.*;
  * {@code 'ignite.{sh|bat} examples/config/example-streamer.xml'}.
  * When starting nodes this way JAR file containing the examples code
  * should be placed to {@code IGNITE_HOME/libs} folder. You can build
- * {@code gridgain-examples.jar} by running {@code mvn package} in
- * {@code IGNITE_HOME/examples} folder. After that {@code gridgain-examples.jar}
+ * {@code ignite-examples.jar} by running {@code mvn package} in
+ * {@code IGNITE_HOME/examples} folder. After that {@code ignite-examples.jar}
  * will be generated by Maven in {@code IGNITE_HOME/examples/target} folder.
  * <p>
  * Alternatively you can run {@link StreamingNodeStartup} in another JVM which will start node
  * with {@code examples/config/example-streamer.xml} configuration.
  */
 public class StreamingPopularNumbersExample {
-    /** Count of most popular numbers to retrieve from grid. */
+    /** Count of most popular numbers to retrieve from ignite. */
     private static final int POPULAR_NUMBERS_CNT = 10;
 
     /** Random number generator. */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPriceBarsExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPriceBarsExample.java b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPriceBarsExample.java
index 06a1d17..b654a17 100644
--- a/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPriceBarsExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/streaming/StreamingPriceBarsExample.java
@@ -78,7 +78,7 @@ public class StreamingPriceBarsExample {
     public static void main(String[] args) throws Exception {
         Timer timer = new Timer("priceBars");
 
-        // Start grid.
+        // Start ignite.
         final Ignite ignite = Ignition.start("examples/config/example-streamer.xml");
 
         System.out.println();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java b/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java
index 71b9946..46bafef 100644
--- a/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java
+++ b/examples/src/main/java8/org/apache/ignite/examples/ComputeExample.java
@@ -19,11 +19,10 @@ package org.apache.ignite.examples;
 
 import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.apache.ignite.lang.IgniteCallable;
 
 /**
- * Demonstrates broadcasting and unicasting computations within grid projection.
+ * Demonstrates broadcasting and unicasting computations within cluster projection.
  * <p>
  * Remote nodes should always be started with special configuration file which
  * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-compute.xml'}.
@@ -40,13 +39,13 @@ public class ComputeExample {
             System.out.println();
             System.out.println(">>> Compute broadcast example started.");
 
-            // Broadcast closure to all grid nodes.
+            // Broadcast closure to all cluster nodes.
             ignite.compute().broadcast((IgniteRunnable)() -> System.out.println("Hello World")).get();
 
-            // Unicast closure to some grid node picked by load balancer.
+            // Unicast closure to some cluster node picked by load balancer.
             ignite.compute().run((IgniteRunnable)() -> System.out.println("Hello World")).get();
 
-            // Unicast closure to some grid node picked by load balancer and return result.
+            // Unicast closure to some cluster node picked by load balancer and return result.
             int length = ignite.compute().call((IgniteCallable<Integer>)"Hello World"::length).get();
 
             System.out.println();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java
----------------------------------------------------------------------
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeCallableExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeCallableExample.java
index 1f50b13..ffb2fad 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeCallableExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeCallableExample.java
@@ -24,7 +24,7 @@ import org.apache.ignite.lang.*;
 import java.util.*;
 
 /**
  * Demonstrates using of {@link org.apache.ignite.lang.IgniteCallable} job execution on the grid.
  * <p>
  * This example takes a sentence composed of multiple words and counts number of non-space
  * characters in the sentence by having each compute job count characters in each individual
@@ -55,14 +55,14 @@ public class ComputeCallableExample {
                 calls.add(new IgniteCallable<Integer>() {
                     @Override public Integer call() throws Exception {
                         System.out.println();
-                        System.out.println(">>> Printing '" + word + "' on this node from grid job.");
+                        System.out.println(">>> Printing '" + word + "' on this node from igntie job.");
 
                         return word.length();
                     }
                 });
             }
 
-            // Execute collection of callables on the grid.
+            // Execute collection of callables on the ignite.
             Collection<Integer> res = ignite.compute().call(calls);
 
             int sum = 0;
@@ -73,7 +73,7 @@ public class ComputeCallableExample {
 
             System.out.println();
             System.out.println(">>> Total number of characters in the phrase is '" + sum + "'.");
-            System.out.println(">>> Check all nodes for output (this node is also part of the grid).");
+            System.out.println(">>> Check all nodes for output (this node is also part of the cluster).");
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/ComputeClosureExample.java
----------------------------------------------------------------------
@@ -24,7 +24,7 @@ import org.apache.ignite.lang.*;
 
 /**
- * Demonstrates using of {@link org.apache.ignite.lang.IgniteCallable} job execution on the grid.
+ * Demonstrates using of {@link org.apache.ignite.lang.IgniteCallable} job execution on the cluster.
  * <p>
  * This example takes a sentence composed of multiple words and counts number of non-space
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeClosureExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeClosureExample.java
index a206a9f..26d959e 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeClosureExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeClosureExample.java
@@ -24,7 +24,7 @@ import org.apache.ignite.lang.*;
 import java.util.*;
 
 /**
- * Demonstrates a simple use of Ignite grid with reduce closure.
+ * Demonstrates a simple use of Ignite with reduce closure.
  * <p>
  * This example splits a phrase into collection of words, computes their length on different
  * nodes and then computes total amount of non-whitespaces characters in the phrase.
@@ -47,12 +47,12 @@ public class ComputeClosureExample {
             System.out.println();
             System.out.println(">>> Compute closure example started.");
 
             // Execute closure on all grid nodes.
             Collection<Integer> res = ignite.compute().apply(
                 new IgniteClosure<String, Integer>() {
                     @Override public Integer apply(String word) {
                         System.out.println();
-                        System.out.println(">>> Printing '" + word + "' on this node from grid job.");
+                        System.out.println(">>> Printing '" + word + "' on this node from igntie job.");
 
                         // Return number of letters in the word.
                         return word.length();
@@ -71,7 +71,7 @@ public class ComputeClosureExample {
 
             System.out.println();
             System.out.println(">>> Total number of characters in the phrase is '" + sum + "'.");
-            System.out.println(">>> Check all nodes for output (this node is also part of the grid).");
+            System.out.println(">>> Check all nodes for output (this node is also part of the cluster).");
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/ComputeContinuousMapperExample.java
----------------------------------------------------------------------
@@ -47,12 +47,12 @@ public class ComputeClosureExample {
             System.out.println(">>> Compute closure example started.");
 
-            // Execute closure on all grid nodes.
+            // Execute closure on all cluster nodes.
             Collection<Integer> res = ignite.compute().apply(
                 new IgniteClosure<String, Integer>() {
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeFibonacciContinuationExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeFibonacciContinuationExample.java
index 8c5e3a4..c58ff82 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeFibonacciContinuationExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeFibonacciContinuationExample.java
@@ -32,7 +32,7 @@ import java.util.*;
 /**
  * This example demonstrates how to use continuation feature of Ignite by
  * performing the distributed recursive calculation of {@code 'Fibonacci'}
  * numbers on the grid. Continuations
  * functionality is exposed via {@link org.apache.ignite.compute.ComputeJobContext#holdcc()} and
  * {@link org.apache.ignite.compute.ComputeJobContext#callcc()} method calls in {@link FibonacciClosure} class.
  * <p>
@@ -77,7 +77,7 @@ public final class ComputeFibonacciContinuationExample {
             System.out.println(">>> Fibonacci sequence for input number '" + N + "' is '" + fib + "'.");
             System.out.println(">>> If you re-run this example w/o stopping remote nodes - the performance will");
             System.out.println(">>> increase since intermediate results are pre-cache on remote nodes.");
-            System.out.println(">>> You should see prints out every recursive Fibonacci execution on grid nodes.");
+            System.out.println(">>> You should see prints out every recursive Fibonacci execution on cluster nodes.");
             System.out.println(">>> Check remote nodes for output.");
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/ComputeProjectionExample.java
----------------------------------------------------------------------
@@ -32,7 +32,7 @@ import java.util.*;
  * This example demonstrates how to use continuation feature of Ignite by
  * performing the distributed recursive calculation of {@code 'Fibonacci'}
- * numbers on the grid. Continuations
+ * numbers on the cluster. Continuations
  * functionality is exposed via {@link org.apache.ignite.compute.ComputeJobContext#holdcc()} and
  * {@link org.apache.ignite.compute.ComputeJobContext#callcc()} method calls in {@link FibonacciClosure} class.
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeTaskMapExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeTaskMapExample.java
index 5127b89..d0ed141 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeTaskMapExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeTaskMapExample.java
@@ -26,10 +26,10 @@ import org.jetbrains.annotations.*;
 import java.util.*;
 
 /**
- * Demonstrates a simple use of Ignite grid with
+ * Demonstrates a simple use of Ignite with
  * {@link org.apache.ignite.compute.ComputeTaskAdapter}.
  * <p>
  * Phrase passed as task argument is split into words on map stage and distributed among grid nodes.
  * Each node computes word length and returns result to master node where total phrase length is
  * calculated on reduce stage.
  * <p>
@@ -51,12 +51,12 @@ public class ComputeTaskMapExample {
             System.out.println();
             System.out.println("Compute task map example started.");
 
             // Execute task on the grid and wait for its completion.
             int cnt = ignite.compute().execute(CharacterCountTask.class, "Hello Grid Enabled World!");
 
             System.out.println();
             System.out.println(">>> Total number of characters in the phrase is '" + cnt + "'.");
-            System.out.println(">>> Check all nodes for output (this node is also part of the grid).");
+            System.out.println(">>> Check all nodes for output (this node is also part of the cluster).");
         }
     }
 
@@ -89,7 +89,7 @@ public class ComputeTaskMapExample {
                 map.put(new ComputeJobAdapter() {
                     @Nullable @Override public Object execute() {
                         System.out.println();
-                        System.out.println(">>> Printing '" + word + "' on this node from grid job.");
+                        System.out.println(">>> Printing '" + word + "' on this node from igntie job.");
 
                         // Return number of letters in the word.
                         return word.length();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/ComputeTaskSplitExample.java
----------------------------------------------------------------------
@@ -26,10 +26,10 @@ import org.jetbrains.annotations.*;
  * {@link org.apache.ignite.compute.ComputeTaskAdapter}.
  * <p>
- * Phrase passed as task argument is split into words on map stage and distributed among grid nodes.
+ * Phrase passed as task argument is split into words on map stage and distributed among cluster nodes.
  * Each node computes word length and returns result to master node where total phrase length is
  * calculated on reduce stage.
@@ -51,12 +51,12 @@ public class ComputeTaskMapExample {
             System.out.println("Compute task map example started.");
 
-            // Execute task on the grid and wait for its completion.
+            // Execute task on the cluster and wait for its completion.
             int cnt = ignite.compute().execute(CharacterCountTask.class, "Hello Grid Enabled World!");
 
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeTaskSplitExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeTaskSplitExample.java
index cf991c2..614c4e6 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/ComputeTaskSplitExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/ComputeTaskSplitExample.java
@@ -25,10 +25,10 @@ import org.jetbrains.annotations.*;
 import java.util.*;
 
 /**
- * Demonstrates a simple use of Ignite grid with {@link org.apache.ignite.compute.ComputeTaskSplitAdapter}.
+ * Demonstrates a simple use of Ignite with {@link org.apache.ignite.compute.ComputeTaskSplitAdapter}.
  * <p>
  * Phrase passed as task argument is split into jobs each taking one word. Then jobs are distributed among
  * grid nodes. Each node computes word length and returns result to master node where total phrase length
  * is calculated on reduce stage.
  * <p>
  * Remote nodes should always be started with special configuration file which
@@ -49,12 +49,12 @@ public class ComputeTaskSplitExample {
             System.out.println();
             System.out.println("Compute task split example started.");
 
             // Execute task on the grid and wait for its completion.
             int cnt = ignite.compute().execute(CharacterCountTask.class, "Hello Grid Enabled World!");
 
             System.out.println();
             System.out.println(">>> Total number of characters in the phrase is '" + cnt + "'.");
-            System.out.println(">>> Check all nodes for output (this node is also part of the grid).");
+            System.out.println(">>> Check all nodes for output (this node is also part of the cluster).");
         }
     }
 
@@ -66,19 +66,19 @@ public class ComputeTaskSplitExample {
          * Splits the received string to words, creates a child job for each word, and sends
          * these jobs to other nodes for processing. Each such job simply prints out the received word.
          *
          * @param gridSize Number of available grid nodes. Note that returned number of
          *      jobs can be less, equal or greater than this grid size.
          * @param arg Task execution argument. Can be {@code null}.
          * @return The list of child jobs.
          */
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, String arg) {
+        @Override protected Collection<? extends ComputeJob> split(int clusterSize, String arg) {
             Collection<ComputeJob> jobs = new LinkedList<>();
 
             for (final String word : arg.split(" ")) {
                 jobs.add(new ComputeJobAdapter() {
                     @Nullable @Override public Object execute() {
                         System.out.println();
-                        System.out.println(">>> Printing '" + word + "' on this node from grid job.");
+                        System.out.println(">>> Printing '" + word + "' on this node from igntie job.");
 
                         // Return number of letters in the word.
                         return word.length();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/failover/ComputeFailoverExample.java
----------------------------------------------------------------------
@@ -25,10 +25,10 @@ import org.jetbrains.annotations.*;
  * <p>
  * Phrase passed as task argument is split into jobs each taking one word. Then jobs are distributed among
- * grid nodes. Each node computes word length and returns result to master node where total phrase length
+ * cluster nodes. Each node computes word length and returns result to master node where total phrase length
  * is calculated on reduce stage.
  * <p>
@@ -49,12 +49,12 @@ public class ComputeTaskSplitExample {
             System.out.println("Compute task split example started.");
 
-            // Execute task on the grid and wait for its completion.
+            // Execute task on the cluster and wait for its completion.
             int cnt = ignite.compute().execute(CharacterCountTask.class, "Hello Grid Enabled World!");
 
@@ -66,19 +66,19 @@ public class ComputeTaskSplitExample {
          * these jobs to other nodes for processing. Each such job simply prints out the received word.
          *
-         * @param gridSize Number of available grid nodes. Note that returned number of
-         *      jobs can be less, equal or greater than this grid size.
+         * @param clusterSize Number of available cluster nodes. Note that returned number of
+         *      jobs can be less, equal or greater than this cluster size.
          * @param arg Task execution argument. Can be {@code null}.
          * @return The list of child jobs.
diff --git a/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskExample.java b/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskExample.java
index e8bbf43..5b2ee04 100644
--- a/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskExample.java
@@ -72,9 +72,9 @@ public final class CreditRiskExample {
             long start = System.currentTimeMillis();
 
             // Calculate credit risk and print it out.
-            // As you can see the grid enabling is completely hidden from the caller
+            // As you can see the ignite enabling is completely hidden from the caller
             // and it is fully transparent to him. In fact, the caller is never directly
             // aware if method was executed just locally or on the 100s of grid nodes.
             // Credit risk crdRisk is the minimal amount that creditor has to have
             // available to cover possible defaults.
 
@@ -112,22 +112,22 @@ public final class CreditRiskExample {
     /**
      * Creates closures for calculating credit risks.
      *
      * @param gridSize Size of the grid.
      * @param portfolio Portfolio.
      * @param horizon Forecast horizon in days.
      * @param iter Number of Monte-Carlo iterations.
      * @param percentile Percentile.
      * @return Collection of closures.
      */
-    private static Collection<IgniteCallable<Double>> jobs(int gridSize, final Credit[] portfolio,
+    private static Collection<IgniteCallable<Double>> jobs(int clusterSize, final Credit[] portfolio,
         final int horizon, int iter, final double percentile) {
         // Number of iterations should be done by each node.
-        int iterPerNode = Math.round(iter / (float)gridSize);
+        int iterPerNode = Math.round(iter / (float)clusterSize);
 
         // Number of iterations for the last/the only node.
-        int lastNodeIter = iter - (gridSize - 1) * iterPerNode;
+        int lastNodeIter = iter - (clusterSize - 1) * iterPerNode;
 
-        Collection<IgniteCallable<Double>> clos = new ArrayList<>(gridSize);
+        Collection<IgniteCallable<Double>> clos = new ArrayList<>(clusterSize);
 
         // Note that for the purpose of this example we perform a simple homogeneous
         // (non weighted) split assuming that all computing resources in this split
@@ -136,8 +136,8 @@ public final class CreditRiskExample {
         // node in the split will be more efficient. It is fairly easy addition and
         // Ignite comes with convenient Spring-compatible benchmark that can be
         // used for weighted splits.
-        for (int i = 0; i < gridSize; i++) {
-            final int nodeIter = i == gridSize - 1 ? lastNodeIter : iterPerNode;
+        for (int i = 0; i < clusterSize; i++) {
+            final int nodeIter = i == clusterSize - 1 ? lastNodeIter : iterPerNode;
 
             clos.add(new IgniteCallable<Double>() {
                 /** {@inheritDoc} */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/compute/montecarlo/CreditRiskManager.java
----------------------------------------------------------------------
@@ -72,9 +72,9 @@ public final class CreditRiskExample {
             // and it is fully transparent to him. In fact, the caller is never directly
-            // aware if method was executed just locally or on the 100s of grid nodes.
+            // aware if method was executed just locally or on the 100s of cluster nodes.
             // Credit risk crdRisk is the minimal amount that creditor has to have
             // available to cover possible defaults.
@@ -112,22 +112,22 @@ public final class CreditRiskExample {
      * Creates closures for calculating credit risks.
      *
-     * @param gridSize Size of the grid.
+     * @param clusterSize Size of the cluster.
      * @param portfolio Portfolio.
      * @param horizon Forecast horizon in days.
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicReferenceExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicReferenceExample.java
index 9e60c6c..8def696 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicReferenceExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicReferenceExample.java
@@ -54,16 +54,16 @@ public final class CacheAtomicReferenceExample {
             // Make value of atomic reference.
             String val = UUID.randomUUID().toString();
 
             // Initialize atomic reference in grid.
             CacheAtomicReference<String> ref = ignite.cache(CACHE_NAME).dataStructures().
                 atomicReference(refName, val, true);
 
             System.out.println("Atomic reference initial value : " + ref.get() + '.');
 
             // Make closure for checking atomic reference value on grid.
             Runnable c = new ReferenceClosure(CACHE_NAME, refName);
 
-            // Check atomic reference on all grid nodes.
+            // Check atomic reference on all clsuter nodes.
             ignite.compute().run(c);
 
             // Make new value of atomic reference.
@@ -73,7 +73,7 @@ public final class CacheAtomicReferenceExample {
 
             ref.compareAndSet("WRONG EXPECTED VALUE", newVal); // Won't change.
 
             // Check atomic reference on all grid nodes.
             // Atomic reference value shouldn't be changed.
             ignite.compute().run(c);
 
@@ -81,14 +81,14 @@ public final class CacheAtomicReferenceExample {
 
             ref.compareAndSet(val, newVal);
 
             // Check atomic reference on all grid nodes.
             // Atomic reference value should be changed.
             ignite.compute().run(c);
         }
 
         System.out.println();
         System.out.println("Finished atomic reference example...");
-        System.out.println("Check all nodes for output (this node is also part of the grid).");
+        System.out.println("Check all nodes for output (this node is also part of the cluster).");
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicSequenceExample.java
----------------------------------------------------------------------
@@ -54,16 +54,16 @@ public final class CacheAtomicReferenceExample {
             String val = UUID.randomUUID().toString();
 
-            // Initialize atomic reference in grid.
+            // Initialize atomic reference in cluster.
             CacheAtomicReference<String> ref = ignite.cache(CACHE_NAME).dataStructures().
                 atomicReference(refName, val, true);
@@ -54,16 +54,16 @@ public final class CacheAtomicReferenceExample {
             System.out.println("Atomic reference initial value : " + ref.get() + '.');
 
-            // Make closure for checking atomic reference value on grid.
+            // Make closure for checking atomic reference value on cluster.
             Runnable c = new ReferenceClosure(CACHE_NAME, refName);
 
@@ -73,7 +73,7 @@ public final class CacheAtomicReferenceExample {
             ref.compareAndSet("WRONG EXPECTED VALUE", newVal); // Won't change.
 
-            // Check atomic reference on all grid nodes.
+            // Check atomic reference on all cluster nodes.
             // Atomic reference value shouldn't be changed.
             ignite.compute().run(c);
@@ -81,14 +81,14 @@ public final class CacheAtomicReferenceExample {
             ref.compareAndSet(val, newVal);
 
-            // Check atomic reference on all grid nodes.
+            // Check atomic reference on all cluster nodes.
             // Atomic reference value should be changed.
             ignite.compute().run(c);
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicSequenceExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicSequenceExample.java
index fc82bbb..6317c3f 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicSequenceExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicSequenceExample.java
@@ -54,7 +54,7 @@ public final class CacheAtomicSequenceExample {
             // Make name of sequence.
             final String seqName = UUID.randomUUID().toString();
 
-            // Initialize atomic sequence in grid.
+            // Initialize atomic sequence in ignite.
             CacheAtomicSequence seq = ignite.cache(CACHE_NAME).dataStructures().atomicSequence(seqName, 0, true);
 
             // First value of atomic sequence on this node.
@@ -62,7 +62,7 @@ public final class CacheAtomicSequenceExample {
 
             System.out.println("Sequence initial value: " + firstVal);
 
             // Try increment atomic sequence on all grid nodes. Note that this node is also part of the grid.
             ignite.compute().run(new SequenceClosure(CACHE_NAME, seqName));
 
             System.out.println("Sequence after incrementing [expected=" + (firstVal + RETRIES) + ", actual=" +
@@ -71,7 +71,7 @@ public final class CacheAtomicSequenceExample {
 
         System.out.println();
         System.out.println("Finished atomic sequence example...");
-        System.out.println("Check all nodes for output (this node is also part of the grid).");
+        System.out.println("Check all nodes for output (this node is also part of the cluster).");
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicStampedExample.java
----------------------------------------------------------------------
@@ -62,7 +62,7 @@ public final class CacheAtomicSequenceExample {
             System.out.println("Sequence initial value: " + firstVal);
 
-            // Try increment atomic sequence on all grid nodes. Note that this node is also part of the grid.
+            // Try increment atomic sequence on all cluster nodes. Note that this node is also part of the cluster.
             ignite.compute().run(new SequenceClosure(CACHE_NAME, seqName));
 
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicStampedExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicStampedExample.java
index ba611fd..dd54374 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicStampedExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheAtomicStampedExample.java
@@ -63,10 +63,10 @@ public final class CacheAtomicStampedExample {
 
             System.out.println("Atomic stamped initial [value=" + stamped.value() + ", stamp=" + stamped.stamp() + ']');
 
-            // Make closure for checking atomic stamped on grid.
+            // Make closure for checking atomic stamped on ignite.
             Runnable c = new StampedUpdateClosure(CACHE_NAME, stampedName);
 
             // Check atomic stamped on all grid nodes.
             ignite.compute().run(c);
 
             // Make new value of atomic stamped.
@@ -79,7 +79,7 @@ public final class CacheAtomicStampedExample {
 
             stamped.compareAndSet("WRONG EXPECTED VALUE", newVal, "WRONG EXPECTED STAMP", newStamp);
 
             // Check atomic stamped on all grid nodes.
             // Atomic stamped value and stamp shouldn't be changed.
             ignite.compute().run(c);
 
@@ -87,14 +87,14 @@ public final class CacheAtomicStampedExample {
 
             stamped.compareAndSet(val, newVal, stamp, newStamp);
 
             // Check atomic stamped on all grid nodes.
             // Atomic stamped value and stamp should be changed.
             ignite.compute().run(c);
         }
 
         System.out.println();
         System.out.println("Finished atomic stamped example...");
-        System.out.println("Check all nodes for output (this node is also part of the grid).");
+        System.out.println("Check all nodes for output (this node is also part of the cluster).");
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheCountDownLatchExample.java
----------------------------------------------------------------------
@@ -63,10 +63,10 @@ public final class CacheAtomicStampedExample {
             Runnable c = new StampedUpdateClosure(CACHE_NAME, stampedName);
 
-            // Check atomic stamped on all grid nodes.
+            // Check atomic stamped on all cluster nodes.
             ignite.compute().run(c);
 
@@ -79,7 +79,7 @@ public final class CacheAtomicStampedExample {
             stamped.compareAndSet("WRONG EXPECTED VALUE", newVal, "WRONG EXPECTED STAMP", newStamp);
 
-            // Check atomic stamped on all grid nodes.
+            // Check atomic stamped on all cluster nodes.
             // Atomic stamped value and stamp shouldn't be changed.
             ignite.compute().run(c);
@@ -87,14 +87,14 @@ public final class CacheAtomicStampedExample {
             stamped.compareAndSet(val, newVal, stamp, newStamp);
 
-            // Check atomic stamped on all grid nodes.
+            // Check atomic stamped on all cluster nodes.
             // Atomic stamped value and stamp should be changed.
             ignite.compute().run(c);
diff --git a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheCountDownLatchExample.java b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheCountDownLatchExample.java
index 9ddb9d7..3ee9c6a 100644
--- a/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheCountDownLatchExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheCountDownLatchExample.java
@@ -54,13 +54,13 @@ public class CacheCountDownLatchExample {
             // Make name of count down latch.
             final String latchName = UUID.randomUUID().toString();
 
-            // Initialize count down latch in grid.
+            // Initialize count down latch in ignite.
             CacheCountDownLatch latch = ignite.cache(CACHE_NAME).dataStructures().
                 countDownLatch(latchName, INITIAL_COUNT, false, true);
 
             System.out.println("Latch initial value: " + latch.count());
 
             // Start waiting on the latch on all grid nodes.
             for (int i = 0; i < INITIAL_COUNT; i++)
                 ignite.compute().run(new LatchClosure(CACHE_NAME, latchName));
 
@@ -72,7 +72,7 @@ public class CacheCountDownLatchExample {
 
         System.out.println();
         System.out.println("Finished count down latch example...");
-        System.out.println("Check all nodes for output (this node is also part of the grid).");
+        System.out.println("Check all nodes for output (this node is also part of the cluster).");
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/datagrid/datastructures/CacheQueueExample.java
----------------------------------------------------------------------
@@ -54,13 +54,13 @@ public class CacheCountDownLatchExample {
             System.out.println("Latch initial value: " + latch.count());
 
-            // Start waiting on the latch on all grid nodes.
+            // Start waiting on the latch on all cluster nodes.
             for (int i = 0; i < INITIAL_COUNT; i++)
                 ignite.compute().run(new LatchClosure(CACHE_NAME, latchName));
diff --git a/examples/src/main/java/org/apache/ignite/examples/misc/lifecycle/LifecycleExample.java b/examples/src/main/java/org/apache/ignite/examples/misc/lifecycle/LifecycleExample.java
index 6462a14..c5e45da 100644
--- a/examples/src/main/java/org/apache/ignite/examples/misc/lifecycle/LifecycleExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/misc/lifecycle/LifecycleExample.java
@@ -63,7 +63,7 @@ public final class LifecycleExample {
      * Simple {@link org.apache.ignite.lifecycle.LifecycleBean} implementation that outputs event type when it is occurred.
      */
     public static class LifecycleExampleBean implements LifecycleBean {
-        /** Auto-inject grid instance. */
+        /** Auto-inject ignite instance. */
         @IgniteInstanceResource
         private Ignite ignite;
 
@@ -76,14 +76,14 @@ public final class LifecycleExample {
             System.out.println(">>> Grid lifecycle event occurred: " + evt);
             System.out.println(">>> Grid name: " + ignite.name());
 
-            if (evt == AFTER_GRID_START)
+            if (evt == AFTER_IGNITE_START)
                 isStarted = true;
-            else if (evt == AFTER_GRID_STOP)
+            else if (evt == AFTER_IGNITE_STOP)
                 isStarted = false;
         }
 
         /**
          * @return {@code True} if grid has been started.
          */
         public boolean isStarted() {
             return isStarted;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/misc/springbean/SpringBeanExample.java
----------------------------------------------------------------------
@@ -76,14 +76,14 @@ public final class LifecycleExample {
 
         /**
-         * @return {@code True} if grid has been started.
+         * @return {@code True} if ignite has been started.
          */
         public boolean isStarted() {
diff --git a/examples/src/main/java/org/apache/ignite/examples/misc/springbean/SpringBeanExample.java b/examples/src/main/java/org/apache/ignite/examples/misc/springbean/SpringBeanExample.java
index 96953d6..f233036 100644
--- a/examples/src/main/java/org/apache/ignite/examples/misc/springbean/SpringBeanExample.java
+++ b/examples/src/main/java/org/apache/ignite/examples/misc/springbean/SpringBeanExample.java
@@ -24,16 +24,16 @@ import org.springframework.context.support.*;
 import java.util.concurrent.*;
 
 /**
- * Demonstrates a simple use of Ignite grid configured with Spring.
+ * Demonstrates a simple use of Ignite configured with Spring.
  * <p>
  * String "Hello World." is printed out by Callable passed into
  * the executor service provided by Grid. This statement could be printed
  * out on any node in the grid.
  * <p>
- * The major point of this example is to show grid injection by Spring
+ * The major point of this example is to show ignite injection by Spring
  * framework. Grid bean is described in {@code spring-bean.xml} file and instantiated
  * by Spring context. Once application completed its execution Spring will
- * apply grid bean destructor and stop the grid.
+ * apply ignite bean destructor and stop the ignite.
  * <p>
  * Remote nodes should always be started with special configuration file which
  * enables P2P class loading: {@code 'ignite.{sh|bat} examples/config/example-compute.xml'}.
@@ -57,7 +57,7 @@ public final class SpringBeanExample {
             new ClassPathXmlApplicationContext("org/apache/ignite/examples/misc/springbean/spring-bean.xml");
 
         try {
             // Get grid from Spring (note that local grid node is already started).
             Ignite ignite = (Ignite)ctx.getBean("mySpringBean");
 
             // Execute any method on the retrieved grid instance.
@@ -77,11 +77,11 @@ public final class SpringBeanExample {
             System.out.println(">>>");
             System.out.println(">>> Finished executing Grid \"Spring bean\" example.");
             System.out.println(">>> You should see printed out of 'Hello world' on one of the nodes.");
-            System.out.println(">>> Check all nodes for output (this node is also part of the grid).");
+            System.out.println(">>> Check all nodes for output (this node is also part of the cluster).");
             System.out.println(">>>");
         }
         finally {
             // Stop local grid node.
             ctx.destroy();
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/921fd0c7/examples/src/main/java/org/apache/ignite/examples/misc/springbean/spring-bean.xml
----------------------------------------------------------------------
@@ -24,16 +24,16 @@ import org.springframework.context.support.*;
  * String "Hello World." is printed out by Callable passed into
  * the executor service provided by Grid. This statement could be printed
- * out on any node in the grid.
+ * out on any node in the cluster.
  * <p>
@@ -57,7 +57,7 @@ public final class SpringBeanExample {
 
         try {
-            // Get grid from Spring (note that local grid node is already started).
+            // Get grid from Spring (note that local cluster node is already started).
             Ignite ignite = (Ignite)ctx.getBean("mySpringBean");
 
@@ -77,11 +77,11 @@ public final class SpringBeanExample {
         }
         finally {
-            // Stop local grid node.
+            // Stop local cluster node.
             ctx.destroy();
         }
diff --git a/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java b/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java
index 89fbdbe..dfe0481 100644
--- a/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java
+++ b/examples/src/main/java8/org/apache/ignite/examples/MessagingExample.java
@@ -26,7 +26,7 @@ import java.util.concurrent.*;
 /**
  * Example that demonstrates how to exchange messages between nodes. Use such
  * functionality for cases when you need to communicate to other nodes outside
- * of grid task.
+ * of ignite task.
  * <p>
  * To run this example you must have at least one remote node started.
  * <p>
@@ -53,7 +53,7 @@ public final class MessagingExample {
         try (Ignite ignite = Ignition.start("examples/config/example-compute.xml")) {
             if (ignite.nodes().size() < 2) {
                 System.out.println();
-                System.out.println(">>> Please start at least 2 grid nodes to run example.");
+                System.out.println(">>> Please start at least 2 cluster nodes to run example.");
                 System.out.println();
 
                 return;
@@ -73,7 +73,7 @@ public final class MessagingExample {
 
             localListen(ignite.forLocal(), orderedLatch, unorderedLatch);
 
             // Register listeners on all grid nodes.
             startListening(rmtPrj);
 
             // Send unordered messages to all remote nodes.
@@ -98,7 +98,7 @@ public final class MessagingExample {
     }
 
     /**
      * Start listening to messages on all grid nodes within passed in projection.
      *
      * @param prj Grid projection.
      * @throws IgniteCheckedException If failed.
@@ -140,7 +140,7 @@ public final class MessagingExample {
     /**
      * Listen for messages from remote nodes.
      *
-     * @param prj Grid projection.
+     * @param prj Projection.
      * @param orderedLatch Latch for ordered messages acks.
      * @param unorderedLatch Latch for unordered messages acks.
      */
@@ -73,7 +73,7 @@ public final class MessagingExample {
             localListen(ignite.forLocal(), orderedLatch, unorderedLatch);
 
-            // Register listeners on all grid nodes.
+            // Register listeners on all cluster nodes.
             startListening(rmtPrj);
 
@@ -98,7 +98,7 @@ public final class MessagingExample {
 
     /**
-     * Start listening to messages on all grid nodes within passed in projection.
+     * Start listening to messages on all cluster nodes within passed in projection.
      *
      * @param prj Grid projection.